% torchlinops documentation master file, created by
% sphinx-quickstart on Fri Feb 16 01:34:36 2024.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# Welcome to torchlinops's documentation!

```{toctree}
:caption: 'Contents:'
:maxdepth: 1

installation
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
